==> pymdown-extensions_10.9.orig.tar.gz: pymdown-extensions-10.9/docs/src/markdown/about/contributing.md <==
# Contributing &amp; Support

## Become a Sponsor :octicons-heart-fill-16:{: .heart-throb}

Open source projects take time and money. Help support the project by becoming a sponsor. You can add your support at
any tier you feel comfortable with. No amount is too little. We also accept one time contributions via PayPal.

[:octicons-mark-github-16: GitHub Sponsors](https://github.com/sponsors/facelessuser){: .md-button .md-button--primary }
[:fontawesome-brands-paypal: PayPal](https://www.paypal.me/facelessuser){ .md-button}

## Bug Reports :material-bug:

1.  Please **read the documentation** and **search the issue tracker** to try and find the answer to your question
    **before** posting an issue.

2.  When creating an issue on the repository, please provide as much info as possible:

    -   Version being used.
    -   Operating system.
    -   Version of Python.
    -   Errors in console.
    -   Detailed description of the problem.
    -   Examples for reproducing the error.  You can post pictures, but if specific text or code is required to
        reproduce the issue, please provide the text in a plain text format for easy copy/paste.

    The more info provided, the greater the chance someone will take the time to answer, implement, or fix the issue.

3.  Be prepared to answer questions and provide additional information if required.  Issues in which the creator refuses
    to respond to follow up questions will be marked as stale and closed.

## Reviewing Code :material-glasses:

Take part in reviewing pull requests and/or reviewing direct commits.  Make suggestions to improve the code and discuss
solutions to overcome weakness in the algorithm.

## Answer Questions in Issues :material-comment-question:

Take time and answer questions and offer suggestions to people who've created issues in the issue tracker. Often people
will have questions that you might have an answer for.  Or maybe you know how to help them accomplish a specific task
they are asking about. Feel free to share your experience to help others out.

## Pull Requests :octicons-git-pull-request-24:

Pull requests are welcome, and a great way to help fix bugs and add new features. If you you are interested in directly
contributing to the code, please check out [Development](./development.md) for more info on the environment and process.

## Documentation Improvements :material-pencil:

A ton of time has been spent not only creating and supporting this tool and related extensions, but also spent making
this documentation.  If you feel it is still lacking, show your appreciation for the tool and/or extensions by helping
to improve the documentation. Check out [Development](./development.md) for more info on documentation.

==> pymdown-extensions_10.13.orig.tar.gz: pymdown-extensions-10.13/docs/src/markdown/about/contributing.md <==
# Contributing &amp; Support

## Become a Sponsor :octicons-heart-fill-16:{: .heart-throb}

Open source projects take time and money. Help support the project by becoming a sponsor. You can add your support at
any tier you feel comfortable with. No amount is too little. We also accept one time contributions via PayPal.

[:octicons-mark-github-16: GitHub Sponsors](https://github.com/sponsors/facelessuser){: .md-button .md-button--primary }
[:fontawesome-brands-paypal: PayPal](https://www.paypal.me/facelessuser){ .md-button}

## Bug Reports :material-bug:

1.  Please **read the documentation** and **search the issue tracker** to try and find the answer to your question
    **before** posting an issue.

2.  When creating an issue on the repository, please provide as much info as possible:

    -   Version being used.
    -   Operating system.
    -   Version of Python.
    -   Errors in console.
    -   Detailed description of the problem.
    -   Examples for reproducing the error.  You can post pictures, but if specific text or code is required to
        reproduce the issue, please provide the text in a plain text format for easy copy/paste.

    The more info provided, the greater the chance someone will take the time to answer, implement, or fix the issue.

3.  Be prepared to answer questions and provide additional information if required.  Issues in which the creator refuses
    to respond to follow up questions will be marked as stale and closed.

## Reviewing Code :material-glasses:

Take part in reviewing pull requests and/or reviewing direct commits.  Make suggestions to improve the code and discuss
solutions to overcome weakness in the algorithm.

## Answer Questions in Issues :material-comment-question:

Take time and answer questions and offer suggestions to people who've created issues in the issue tracker. Often people
will have questions that you might have an answer for.  Or maybe you know how to help them accomplish a specific task
they are asking about. Feel free to share your experience to help others out.

## Pull Requests :octicons-git-pull-request-24:

Pull requests are welcome, and a great way to help fix bugs and add new features. If you are interested in directly
contributing to the code, please check out [Development](./development.md) for more info on the environment and process.

## Documentation Improvements :material-pencil:

A ton of time has been spent not only creating and supporting this tool and related extensions, but also spent making
this documentation.  If you feel it is still lacking, show your appreciation for the tool and/or extensions by helping
to improve the documentation. Check out [Development](./development.md) for more info on documentation.
